==> converseen-0.6.8.tar.bz2: converseen-0.6.8/README.md <==
# Converseen

![alt text](http://converseen.sourceforge.net/res/converseen1.png "Converseen on Kde")

**Converseen** is an open source project written in **C++** with the powerful **Qt4** libraries.
Thanks to the **Magick++** image libraries it supports more than **100 image formats**.
You can convert an unlimited number of images and / or create thumbnails
to any of the most popular formats: DPX, EXR, GIF, JPEG, JPEG-2000, PDF, PhotoCD, PNG, Postscript, SVG, and TIFF.
With **Converseen** you can save your time because it allows you to process more than one image with a mouse click!
**Converseen** is very simple: it features a very simple user interface without strange options.

## What you can do with *Converseen*?

With converseen you can:
* Carry out a single or a multiple conversion.
* Resize one or multiple images.
* Compress images for your web pages.

## Installing

**Converseen** is available for both **Linux** and **Windows** platforms.  
To install **Converseen** source or binaries follow [these instructions](http://converseen.sourceforge.net/index.php?page=1).  

## Author

[Francesco Mondello](http://converseen.sourceforge.net/).  
To contact me you can use [this page](http://converseen.sourceforge.net/index.php?page=4).  
  
  
You can find more details about **Converseen** at [converseen.sf.net](http://converseen.sourceforge.net/).  
If you appreciate this work and would like to support the project, you are welcome to [donate](http://converseen.sourceforge.net/#donations) **1 EUR** via **Paypal**.  

## License
 
    Converseen - The image batch converter and resizer
    Copyright (C) 2009-2013  Francesco Mondello

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

==> converseen_0.7.2.orig.tar.bz2: converseen-0.7.2/README.md <==
[![Flattr this git repo](http://api.flattr.com/button/flattr-badge-large.png)](https://flattr.com/submit/auto?user_id=faster3ck&url=https://github.com/Faster3ck/Converseen&title=Converseen&language=&tags=github&category=software)

# Converseen

![alt text](http://converseen.fasterland.net/res/converseen_kde4_1.jpg "Converseen on Kde")

**Converseen** is an open source project written in **C++** with the powerful **Qt4** libraries.
Thanks to the **Magick++** image libraries it supports more than **100 image formats**.
You can convert an unlimited number of images and / or create thumbnails
to any of the most popular formats: DPX, EXR, GIF, JPEG, JPEG-2000, PDF, PhotoCD, PNG, Postscript, SVG, and TIFF.
With **Converseen** you can save your time because it allows you to process more than one image with a mouse click!
**Converseen** is very simple: it features a very simple user interface without strange options.

## What you can do with *Converseen*?

With converseen you can:
* Carry out a single or a multiple conversion.
* Resize one or multiple images.
* Compress images for your web pages.

## Installing

**Converseen** is available for both **Linux** and **Windows** platforms.  
To install **Converseen** source or binaries follow [these instructions](http://http://converseen.fasterland.net/download-for-linux/).  

## Author

[Francesco Mondello](http://converseen.fasterland.net/).  
To contact me you can use [this page](http://converseen.fasterland.net/contact-me/).  
  
  
You can find more details about **Converseen** at [converseen.sf.net](http://converseen.fasterland.net/).  
If you appreciate this work and would like to support the project, you are welcome to [donate](http://converseen.fasterland.net/#donations) **1 EUR** via **Paypal**.  

## License
 
    Converseen - The image batch converter and resizer
    Copyright (C) 2009-2013  Francesco Mondello

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
